@@ -14,8 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-# from sudsds import WebFault
-# from sudsds.transport import TransportError
+import calculate.contrib
 from suds.transport import TransportError
 from suds import WebFault
 import logging
