@@ -581,7 +581,7 @@ class CoreWsdl(CoreServiceInterface):
         dv = cls.get_cache(sid, method_name, "vars")
         try:
             if not dv:
-                dv = getattr(cls, "%s_vars" % method_name)()
+                dv = getattr(cls, "%s_vars" % method_name)(cls)
             else:
                 callbackRefresh(cls, sid, dv)
                 dv.processRefresh()
