@@ -17,7 +17,7 @@
 import urllib2 as u2
 import os
 import sys
-# from sudsds.transport.http import HttpTransport
+import calculate.contrib
 from suds.transport.http import HttpTransport
 from httplib import HTTPConnection, HTTPSConnection
 import socket
