@@ -59,28 +59,30 @@ class LocalCall(object):
     gui_warning = None
     no_questions = None
 
-    def startprocess(self, sid, target=None, method=None, method_name=None,
+    @staticmethod
+    def startprocess(cls, sid, target=None, method=None, method_name=None,
                      auto_delete=False, args_proc=()):
         """ start process """
         if "LANG" in os.environ:
             curThread = threading.currentThread()
             curThread.lang = os.environ["LANG"]
-        com = target(self.no_progress, self.gui_progress, self.gui_warning,
-                     self.no_questions)
+        com = target(cls.no_progress, cls.gui_progress, cls.gui_warning,
+                     cls.no_questions)
         if len(com.__class__.__bases__) > 1 and \
                 hasattr(com.__class__.__bases__[1], '__init__'):
             com.__class__.__bases__[1].__init__(com)
         com.method_name = method_name
         com.method_status = ProcessStatus.Worked
         if getattr(com, method)(*args_proc):
-            self.method_status = ProcessStatus.SuccessFinished
+            cls.method_status = ProcessStatus.SuccessFinished
         else:
-            self.method_status = ProcessStatus.FailedFinished
-        com.method_status = self.method_status
-        self.del_pid_file(os.getpid(), com.clVars)
+            cls.method_status = ProcessStatus.FailedFinished
+        com.method_status = cls.method_status
+        cls.del_pid_file(cls, os.getpid(), com.clVars)
         return 0
 
-    def del_pid_file(self, pid, clVars=None):
+    @staticmethod
+    def del_pid_file(cls, pid, clVars=None):
         if clVars:
             pids = clVars.Get('core.cl_core_pids_path')
         else:
@@ -175,7 +177,7 @@ def cout_progress(string=None):
     sys.stdout.flush()
 
 
-def local_method(metaclass, args, unknown_args):
+def local_method(metaObject, args, unknown_args):
     """
     Call method from metaclass, check method existing.
 
@@ -199,7 +201,7 @@ def local_method(metaclass, args, unknown_args):
         return 0
 
     colorPrint = color_print()
-    metaObject = metaclass()
+    # metaObject = metaclass()
     method_name = args.method
     method_view_name = method_name + '_view'
     if args.method and args.help:
@@ -215,7 +217,7 @@ def local_method(metaclass, args, unknown_args):
             view_obj.dispatch_usenew = \
                 force_param
             try:
-                view = getattr(metaObject, method_view_name)(0, view_obj)
+                view = getattr(metaObject, method_view_name)(metaObject, 0, view_obj)
             except AttributeError:
                 colorPrint.printERROR(_('Method not found: ') + method_view_name)
                 return 1
@@ -285,7 +287,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
         view_obj.dispatch_usenew = dispatch_usenew
 
         try:
-            view = getattr(metaObject, method_view_name)(0, view_obj)
+            view = getattr(metaObject, method_view_name)(metaObject, 0, view_obj)
         except AttributeError:
             colorPrint.printERROR(_('Method not found: ') + method_name)
             return None
@@ -331,7 +333,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
         setattr(param_object, 'CheckOnly', True)
         check_res = {}
         while True:
-            method_result = getattr(metaObject, method_name)(0, param_object)
+            method_result = getattr(metaObject, method_name)(metaObject, 0, param_object)
             if not method_result:
                 print _('Method not available')
                 return None
@@ -357,7 +359,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
         view_obj.conargs = [x[0] for x in args._get_kwargs() if x[1] is not None]
         view_obj.dispatch_usenew = dispatch_usenew
         try:
-            view = getattr(metaObject, method_view_name)(0, view_obj)
+            view = getattr(metaObject, method_view_name)(metaObject, 0, view_obj)
         except AttributeError:
             colorPrint.printERROR(_('Method not found: ') + method_name)
 
@@ -384,7 +386,7 @@ def call_method(metaObject, args, unknown_args, colorPrint):
     try:
         check_res = {}
         while True:
-            method_result = getattr(metaObject, method_name)(0, param_object)
+            method_result = getattr(metaObject, method_name)(metaObject, 0, param_object)
             if not method_result:
                 colorPrint.printERROR(_('method unavailable'))
                 return None
