@@ -21,21 +21,21 @@ from cert_cmd import find_cert_id
 DAY_CERT = 600
 
 
-def serv_post_cert(self):
+def serv_post_cert(cls):
     """ transfer the client certificate """
     cur_thread = threading.currentThread()
     certificate = cur_thread.client_cert
     if certificate is None:
         return [-3]
 
-    checked_id = find_cert_id(certificate, self.data_path, self.certbase)
+    checked_id = find_cert_id(certificate, cls.data_path, cls.certbase)
     try:
         if int(checked_id) < 1:
             return [-2]
     except ValueError:
         return [-4]
     results = []
-    with open(self.certbase) as fd:
+    with open(cls.certbase) as fd:
         t = fd.read()
         # See each line
         for line in t.splitlines():
