@@ -14,18 +14,16 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from soaplib.wsgi import Application
+from spyne.server.wsgi import WsgiApplication
+
 import re
 import logging
 import os
+#cStringIO was moved to io in python3
+import cStringIO as io
 
 logger = logging.getLogger(__name__)
-from lxml import etree
-from lxml.etree import XMLSyntaxError
-import soaplib
-from soaplib.serializers.exception import Fault
-from soaplib.serializers.primitive import string_encoding
-from soaplib.soap import apply_mtom
+
 import datetime
 import pickle
 from loaded_methods import LoadedMethods
@@ -43,25 +41,15 @@ not_log_list = ['post_server_request', 'post_client_request', 'del_sid',
                 'get_crl', 'get_server_host_name', 'get_ca', 'get_table',
                 'post_cert', 'post_sid', 'active_client', 'list_pid',
                 'get_methods', 'get_frame', 'get_progress', 'pid_info']
+  
 
-
-class ClApplication(Application):
-    def __init__(self, services, tns, name=None, _with_partnerlink=False,
-                 log=None):
-        """
-        @param services: A ServiceBase subclass that
-                        defines the exposed services.
-        """
-        Application.__init__(self, services, tns)
+class ClApplication(WsgiApplication):
+    def __init__(self, app, log=None):
+        super(ClApplication, self).__init__(app)
         # add object logging
-        self.log = log
-        # access to private members for pycharm
-        self.__get_method_name = getattr(self, "_Application__get_method_name")
-        self.__decode_soap_request = (
-            getattr(self, "_Application__decode_soap_request"))
-        self.__handle_fault = getattr(self, "_Application__handle_fault")
+        self.log = logger
 
-    # verification of compliance certificate and session (sid)
+    #verification of compliance certificate and session (sid)
     def check_cert_sid(self, sid, server):
         import threading
 
@@ -94,13 +82,13 @@ class ClApplication(Application):
         return 0
 
     # input parameters - certificate and name method
-    def check_rights(self, method_name, req_env, params):
+    def check_rights(self, method_name, req_env, sid):
         """ check right client certificate for the method """
         import OpenSSL
 
-        rmethod = re.compile('[{\w]+[}]')
-        method_rep = rmethod.findall(method_name)
-        method_name = method_name.replace(method_rep[0], '')
+        # rmethod = re.compile('[{\w]+[}]')
+        # method_rep = rmethod.findall(method_name)
+        # method_name = method_name.replace(method_rep[0], '')
         import threading
 
         curthread = threading.currentThread()
@@ -123,14 +111,12 @@ class ClApplication(Application):
                 return 0
             return 1
 
-        if params:
-            if (hasattr(params, 'sid') and
-                    (method_name in LoadedMethods.rightsMethods or
-                             method_name.endswith('_view') and
-                                 method_name[
-                                 :-5] in LoadedMethods.rightsMethods)):
-                if not self.check_cert_sid(params.sid, curthread.server):
-                    return 0
+        if (sid and
+            (method_name in LoadedMethods.rightsMethods or
+            method_name.endswith('_view') and
+            method_name[:-5] in LoadedMethods.rightsMethods)):
+            if not self.check_cert_sid(sid, curthread.server):
+                return 0
 
         with open(server_cert, 'r') as f:
             data_server_cert = f.read()
@@ -286,216 +272,112 @@ class ClApplication(Application):
         if not os.path.exists(cert_path):
             os.makedirs(cert_path)
 
-    def _Application__handle_soap_request(self, req_env, start_response, url):
+
+    def get_method_name_from_http(self, http_req_env):
+        retval = None
+        # check HTTP_SOAPACTION
+        retval = http_req_env.get("HTTP_SOAPACTION")
+
+        if retval is not None:
+            if retval.startswith('"') and retval.endswith('"'):
+                retval = retval[1:-1]
+
+            if retval.find('/') >0:
+                retvals = retval.split('/')
+                retval = '{%s}%s' % (retvals[0], retvals[1])
+
+            logger.debug("\033[92m"
+                            "Method name from HTTP_SOAPACTION: %r"
+                            "\033[0m" % retval)
+        if(not retval):                  
+            logger.critical("Couldn't get method name from HTTP_SOAPACTION")
+        return retval
+
+    def get_sid_from_soap(self, http_req_env):
         """
-        This function is too big.
+        rips sid param from soap request (if there is one)  
+        """
+        if (not "wsgi.input" in http_req_env):
+            return None
+        length = http_req_env.get("CONTENT_LENGTH")
+        input = http_req_env["wsgi.input"]
+        body = input.read(int(length))
+        res = re.search("<ns.:sid>(.*?)<\/ns.:sid>", body)
+        #horrbile hack:
+        #cherrypy provides rfile in req_env which is consumed upon .read() without 
+        #        workarounds, and both we and spyne need the data on it
+        #so we pass a dummy with the data and read() method on to spyne
+        http_req_env["wsgi.input"] = io.StringIO(body)
+        
+        if(res):
+            return int(res.group(1))
+        else:
+            return None
+
+    
+    def handle_rpc(self, req_env, start_response):
+        """
+        Overriding spyne.wsgiApplication method
         """
         import OpenSSL
         import threading
-
-        curthread = threading.currentThread()
-        curthread.REMOTE_ADDR = req_env.get('REMOTE_ADDR')
-        curthread.REMOTE_PORT = req_env.get('REMOTE_PORT')
-        ip = req_env.get('REMOTE_ADDR')
-
         http_resp_headers = {
             'Content-Type': 'text/xml',
             'Content-Length': '0',
         }
-        service = None
-
+        curthread = threading.currentThread()
+        curthread.REMOTE_ADDR = req_env.get('REMOTE_ADDR')
+        curthread.REMOTE_PORT = req_env.get('REMOTE_PORT')
+        ip = req_env.get('REMOTE_ADDR')
         self.create_path()
-        try:
-            # implementation hook
-            self.on_call(req_env)
+        sid = self.get_sid_from_soap(req_env)
+        method_name = self.get_method_name_from_http(req_env)
+        if method_name is None:
+            resp = "Could not extract method name from the request!"
+            http_resp_headers['Content-Length'] = str(len(resp))
+            start_response(HTTP_500, http_resp_headers.items())
+            return [resp]
 
-            if req_env['REQUEST_METHOD'].lower() != 'post':
-                http_resp_headers['Allow'] = 'POST'
-                start_response(HTTP_405, http_resp_headers.items())
-                return ['']
+        service = self.app.services[0]
+        import threading
 
-            input = req_env.get('wsgi.input')
-            length = req_env.get("CONTENT_LENGTH")
-            body = input.read(int(length))
-
-            try:
-                service = None
-                soap_req_header, soap_req_payload = self.__decode_soap_request(
-                    req_env, body)
-                if not (soap_req_payload is None):
-                    self.validate_request(soap_req_payload)
-
-                method_name = self.__get_method_name(req_env, soap_req_payload)
-                if method_name is None:
-                    resp = "Could not extract method name from the request!"
-                    http_resp_headers['Content-Length'] = str(len(resp))
-                    start_response(HTTP_500, http_resp_headers.items())
-                    return [resp]
-
-                service_class = self.get_service_class(method_name)
-                service = self.get_service(service_class, req_env)
-
-            finally:
-                # for performance reasons, we don't want the following to run
-                # in production even though we won't see the results.
-                if logger.level == logging.DEBUG:
-                    try:
-                        logger.debug(etree.tostring(etree.fromstring(body),
-                                                    pretty_print=True))
-                    except XMLSyntaxError as e:
-                        logger.debug(body)
-                        raise Fault('Client.XMLSyntax',
-                                    'Error at line: %d, col: %d'
-                                    # for pycharm
-                                    % getattr(e, "position"))
-
-            # retrieve the method descriptor
-            descriptor = service.get_method(method_name)
-            func = getattr(service, descriptor.name)
-
-            # decode header object
-            if soap_req_header is not None and len(soap_req_header) > 0:
-                in_header = descriptor.in_header
-                service.soap_in_header = in_header.from_xml(soap_req_header)
-
-            # decode method arguments
-            if soap_req_payload is not None and len(soap_req_payload) > 0:
-                params = descriptor.in_message.from_xml(soap_req_payload)
-            else:
-                params = [None] * len(descriptor.in_message._type_info)
-                # check_rights
-            import threading
-
-            curthread = threading.currentThread()
-            # check exists client certificate
-            if not hasattr(curthread, 'client_cert'):
-                curthread.client_cert = None
-            # check rights client certificate for the method
-            check = self.check_rights(method_name, req_env, params)
-            if not check:
-                if curthread.client_cert:
-                    certobj = OpenSSL.crypto.load_certificate(
-                        OpenSSL.SSL.FILETYPE_PEM, curthread.client_cert)
-                    finger = certobj.digest('SHA1')
-                    if self.log:
-                        self.log.debug('%s %s %s forbidden %s'
-                                       % (datetime.datetime.now().__str__(),
-                                          finger, ip,
-                                          method_name[5:]))
-                resp = "Permission denied: " + method_name
-                http_resp_headers['Content-Length'] = str(len(resp))
-                start_response(HTTP_403, http_resp_headers.items())
-                return [resp]
-            if hasattr(params, 'sid'):
-                curthread.lang = service.get_lang(params.sid, method_name)
+        curthread = threading.currentThread()
+        # check if client certificate exists
+        if not hasattr(curthread, 'client_cert'):
+            curthread.client_cert = None
+        # check rights client certificate for the method
+        check = self.check_rights(method_name, req_env, sid)
+        if not check:
             if curthread.client_cert:
                 certobj = OpenSSL.crypto.load_certificate(
                     OpenSSL.SSL.FILETYPE_PEM, curthread.client_cert)
                 finger = certobj.digest('SHA1')
-                if (not method_name[5:] in not_log_list and
-                        not method_name[5:].endswith('_view')):
-                    if self.log:
-                        self.log.debug('%s %s %s allowed %s'
-                                       % (datetime.datetime.now().__str__(),
-                                          finger, ip,
-                                          method_name[5:]))
-
-            # implementation hook
-            service.on_method_call(req_env, method_name, params,
-                                   soap_req_payload)
-
-            # call the method
-            result_raw = service.call_wrapper(func, params)
-
-            # construct the soap response, and serialize it
-            envelope = etree.Element('{%s}Envelope' % soaplib.ns_soap_env,
-                                     nsmap=soaplib.nsmap)
-
-            #
-            # header
-            #
-            soap_header_elt = etree.SubElement(
-                envelope, '{%s}Header' % soaplib.ns_soap_env)
-
-            if service.soap_out_header is None:
-                if descriptor.out_header is None:
-                    logger.warning("Skipping soap response header as %r "
-                                   "method is not published to have a soap "
-                                   "response header" % method_name)
-                else:
-                    descriptor.out_header.to_xml(
-                        service.soap_out_header,
-                        self.get_tns(),
-                        soap_header_elt,
-                        descriptor.out_header.get_type_name()
-                    )
-            if len(soap_header_elt) > 0:
-                envelope.append(soap_header_elt)
-
-            #
-            # body
-            #
-            soap_body = etree.SubElement(envelope,
-                                         '{%s}Body' % soaplib.ns_soap_env)
-
-            # instantiate the result message
-            result_message = descriptor.out_message()
-
-            # assign raw result to its wrapper, result_message
-            out_type = descriptor.out_message._type_info
-
-            if len(out_type) > 0:
-                if len(out_type) == 1:
-                    attr_name = descriptor.out_message._type_info.keys()[0]
-                    setattr(result_message, attr_name, result_raw)
-                else:
-                    for i in range(len(out_type)):
-                        attr_name = descriptor.out_message._type_info.keys()[i]
-                        setattr(result_message, attr_name, result_raw[i])
-
-            # transform the results into an element
-            descriptor.out_message.to_xml(result_message, self.get_tns(),
-                                          soap_body)
-            # implementation hook
-            service.on_method_return(req_env, result_raw, soap_body,
-                                     http_resp_headers)
-
-            #
-            # misc
-            #
-            results_str = etree.tostring(envelope, xml_declaration=True,
-                                         encoding=string_encoding)
-
-            if descriptor.mtom:
-                http_resp_headers, results_str = apply_mtom(
-                    http_resp_headers, results_str,
-                    descriptor.out_message._type_info, [result_raw])
-
-            # implementation hook
-            self.on_return(req_env, http_resp_headers, results_str)
-
-            # initiate the response
-            http_resp_headers['Content-Length'] = str(len(results_str))
-            start_response(HTTP_200, http_resp_headers.items())
-
-            if logger.level == logging.DEBUG:
-                logger.debug('\033[31m' + "Response" + '\033[0m')
-                logger.debug(etree.tostring(envelope, xml_declaration=True,
-                                            pretty_print=True))
-            # return the serialized results
-            return [results_str]
-
-        # The user issued a Fault, so handle it just like an exception!
-        except Fault as e:
-            return self.__handle_fault(req_env, start_response,
-                                       http_resp_headers, service, e)
-
-        except Exception as e:
-            fault = Fault('Server', str(e))
-
-            return self.__handle_fault(req_env, start_response,
-                                       http_resp_headers, service, fault)
+                if self.log:
+                    self.log.debug('%s %s %s forbidden %s'
+                                    % (datetime.datetime.now().__str__(),
+                                        finger, ip,
+                                        method_name[5:]))
+            resp = "Permission denied: " + method_name
+            http_resp_headers['Content-Length'] = str(len(resp))
+            start_response(HTTP_403, http_resp_headers.items())
+            return [resp]
+        
+        
+        if sid:
+            curthread.lang = service.get_lang(service, sid, method_name)
+        if curthread.client_cert:
+            certobj = OpenSSL.crypto.load_certificate(
+                OpenSSL.SSL.FILETYPE_PEM, curthread.client_cert)
+            finger = certobj.digest('SHA1')
+            if (not method_name[5:] in not_log_list and
+                    not method_name[5:].endswith('_view')):
+                if self.log:
+                    self.log.debug('%s %s %s allowed %s'
+                                    % (datetime.datetime.now().__str__(),
+                                        finger, ip,
+                                        method_name[5:]))
 
+        return super(ClApplication, self).handle_rpc(req_env, start_response)
 
 class OpenSSLAdapter(pyOpenSSLAdapter):
     def verify_func(self, connection, x509, errnum, errdepth, ok):
